VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "ImageProcessing"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' +-------------------------------- DISCLAIMER ---------------------------------+
' |                                                                             |
' | This application program is provided to you free of charge as an example.   |
' | Despite the considerable efforts of Euresys personnel to create a usable    |
' | example, you should not assume that this program is error-free or suitable  |
' | for any purpose whatsoever.                                                 |
' |                                                                             |
' | EURESYS does not give any representation, warranty or undertaking that this |
' | program is free of any defect or error or suitable for any purpose. EURESYS |
' | shall not be liable, in contract, in torts or otherwise, for any damages,   |
' | loss, costs, expenses or other claims for compensation, including those     |
' | asserted by third parties, arising out of or in connection with the use of  |
' | this program.                                                               |
' |                                                                             |
' +-----------------------------------------------------------------------------+

Option Explicit

Option Base 0

' The source image
Dim srcImg As New EImageBW8

' Geometrical pattern matching tool
Dim finder As New EPatternFinder
Dim foundPattern() As EFoundPattern

' EWorldShape which holds the measurement tools
Dim worldShape As New EWorldShape

' Flags
Dim bBlown As Boolean
Dim bFound As Boolean

Public Sub Initialize()

    On Error GoTo Failure
    
    Dim sPath As String
    sPath = Left(App.Path, InStrRev(App.Path, "\") - 1)
    
    ' Load the EasyFind model file
    finder.Load sPath & "\Resources\Model\Fuse.FND", True
    
    'Load the EasyGauge model file
    worldShape.Load sPath & "\Resources\Model\Fuse.GGE", True
    
    On Error GoTo 0
    Exit Sub
    
Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "FuseInspection"
                
End Sub

Public Sub Inspect(Filename As String)

    ' Reset the flags
    bBlown = False
    bFound = False
    
    On Error GoTo Failure
 
    'Load the image for inspection
    srcImg.Load Filename
    
    ' If the EasyFind model file loading failed, exit
    If finder.LearningDone = False Then
        Exit Sub
    End If
        
    ' Find the Fuse
    foundPattern = finder.Find(srcImg)
    
    ' If no instance has been found, exit
    If UBound(foundPattern) < 0 Then
        Exit Sub
    End If
            
    ' Retrieve the found pattern center coordinates (in Sensor space)
    Dim sensorFrameCenter As New EPoint
    sensorFrameCenter.SetCenterXY foundPattern(0).Center.X, foundPattern(0).Center.Y
    
    ' As the field of view is calibrated, it is necessary to convert the
    ' instance coordinates from the Sensor space (pixels) to the World space (mm)
    Dim worldFrameCenter As EPoint
    Set worldFrameCenter = worldShape.SensorToWorld(sensorFrameCenter)
    
    ' Move the FrameShape to the relevant location
    Dim frameShape As EFrameShape
    Set frameShape = worldShape.GetShapeNamed("EFrameShape1")
    frameShape.SetCenterXY worldFrameCenter.X, worldFrameCenter.Y
    frameShape.angle = (-1) * foundPattern(0).angle
    
    ' Perform the measurement
    worldShape.Process srcImg, True

    ' Retrieve the number of valid points
    Dim line As ELineGauge
    Dim numSamples As Integer
    Dim numValidSamples As Integer
        
    Set line = worldShape.GetShapeNamed("ELineGauge1")
    numSamples = line.numSamples
    numValidSamples = line.numValidSamples

    ' If less than 75% of the sample points are valid, then the fuse is blown
    If (numSamples - numValidSamples) > (numSamples / 4) + 1 Then
    
        ' Update the flag
        bBlown = True
        
    End If

    ' Update the flag
    bFound = True
                
    On Error GoTo 0
    Exit Sub
    
Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "FuseInspection"
    
End Sub

Public Sub Draw(hdc As Long)

    On Error GoTo Failure
 
    ' Draw the image into the PictureBox
    srcImg.Draw hdc
    
    ' If no fuse was found, exit
    If bFound = False Then
        Exit Sub
    End If
        
    Dim str As String
    Dim strTmp As String
    str = "ELineGauge"
    Dim line As ELineGauge
    Dim i As Integer
            
    ' Draw the gauges measuring the fuse leads
    For i = 3 To 10
    
        strTmp = str + CStr(i)
        Set line = worldShape.GetShapeNamed(strTmp)
        line.Draw hdc, EDrawingMode_Nominal
        line.Draw hdc, EDrawingMode_Actual
        
    Next
    
    ' Draw green lines if the fuse is not blown
    If bBlown = False Then
    
        Set line = worldShape.GetShapeNamed("ELineGauge1")
        line.Draw hdc, EDrawingMode_Actual

        Set line = worldShape.GetShapeNamed("ELineGauge2")
        line.Draw hdc, EDrawingMode_Actual
        
    End If
    
    ' Draw red lines if the fuse is blown
    If bBlown = True Then
    
        ' Specify the color for drawing
        Dim redColor As ERGBColor
        redColor.Red = 255
            
        Set line = worldShape.GetShapeNamed("ELineGauge1")
        line.DrawWithColor hdc, redColor, EDrawingMode_Actual
            
        Set line = worldShape.GetShapeNamed("ELineGauge2")
        line.DrawWithColor hdc, redColor, EDrawingMode_Actual
        
    End If
          
    On Error GoTo 0
    Exit Sub
    
Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "FuseInspection"

End Sub

